@@ -10,10 +10,15 @@ from os import path
 from typing import Dict, Any
 from sphinx.application import Sphinx
 
-__version__ = "1.1.0"
-
+__version__ = "1.5.0"
 
 def setup(app: Sphinx) -> Dict[str, Any]:
     """register this theme with Sphinx"""
 
     app.add_html_theme("sphinxawesome_theme", path.abspath(path.dirname(__file__)))
+
+    return {
+        "version": __version__,
+        "parallel_read_safe": True,
+        "parallel_write_safe": True,
+    }
